#!/bin/bash
#
# Create/clone new projects from AOSP, based on AOSP manifest.
# This script is intended to be run as a cronjob.
#

BASE_DIR=/mnt/upstream-mirror
MIRROR_DIR=$BASE_DIR/gerrit-mirror

# We fetch manifest from out tree because, well, our tree is mirror of upstream
#MANIFEST="http://android.git.linaro.org/gitweb?p=platform/manifest.git;a=blob_plain;f=default.xml;hb=HEAD"
#MANIFEST="http://android.git.linaro.org/gitweb?p=platform/manifest.git;a=blob_plain;f=default.xml;hb=refs/heads/linaro_android_4.0.3"
#MANIFEST="http://android.git.linaro.org/gitweb?p=platform/manifest.git;a=blob_plain;f=base-for-3.0-gpl.xml;hb=refs/heads/master"

GITWEB_LIST="https://android.googlesource.com/?format=TEXT"

fatal () {
    echo $1
    exit 1
}

# Require explicit flag to clone new projects, to avoid spurious clones when
# run on a local system to just create new projects. Should be specified
# first if any other options are given.
if [ "$1" == "--clone" ]; then
    clone=1
    shift
fi

#wget "$MANIFEST" -q -O manifest-for-create.xml || fatal "Error getting $MANIFEST"
wget "$GITWEB_LIST" -q -O aosp-projects.txt || fatal "Error getting $GITWEB_LIST"

./git-gerrit-mirror --mirror-dir=$MIRROR_DIR \
    create --upstream=google --gitweb-list=aosp-projects.txt $*

if [ -n "$clone" ]; then
    # First clone AOSP projects, guided by aosp-projects.txt
    ./git-gerrit-mirror --mirror-dir=$MIRROR_DIR \
        clone  --upstream=google --gitweb-list=aosp-projects.txt $*

    # Then, clone any other new projects, guided by mirror.conf
    ./git-gerrit-mirror --mirror-dir=$MIRROR_DIR --quiet clone $*
fi
